@@ -51,7 +51,21 @@ config_network(){
   eth_port_no="$(get-nic-devs | wc -l)"
   configured_ip_no="$(get-all-nic-ip -i | wc -w)"
   while [ "$configured_ip_no" -lt "$eth_port_no" ]; do
-    ocs-live-netcfg
+    [ -n "$(route -n | grep -E "^0.0.0.0")" ] && config_gw_opt="--ignore-gw"
+    [ -n "$(grep -E "^[[:space:]]*nameserver[[:space:]]+\b(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b" /etc/resolv.conf)" ] && config_dns_opt="--ignore-dns"
+    # find the configured ports, we will exclude them.
+    eth_ports="$(get-nic-devs)"
+    configured_port_list=""
+    for i in $eth_ports; do
+      if [ -n "$(get_ip $i)" ]; then
+       configured_port_list="$configured_port_list $i"
+      fi
+    done
+    if [ -n "$configured_port_list" ]; then
+      ocs-live-netcfg $config_gw_opt $config_dns_opt --ignore-dv "$configured_port_list"
+    else
+      ocs-live-netcfg $config_gw_opt $config_dns_opt
+    fi
     configured_ip_no="$(get-all-nic-ip -i | wc -w)"
     [ "$configured_ip_no" -eq "$eth_port_no" ] && break
     [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
@@ -183,7 +197,9 @@ case "$switch" in
      #
      echo "$msg_delimiter_star_line"
      echo "$msg_done!"
+     [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
      echo "$msg_all_set_you_can_turn_on_clients"
+     [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
      echo -n $msg_press_enter_to_continue
      read
      ;;
